@@ -1,5 +1,4 @@
 from __future__ import print_function
-import sys
 
 import tkinter as tk
 from tkinter import ttk
@@ -17,9 +16,9 @@ def generate_summary(tnorm_app):
         except ValueError:
             sym_group = 'Failed'
         sections = ['Manifold', 'Thurston norm ball', 'Normal surfaces']
-        names = [('rank H_2(M;bdy M)', 'volume', 'num tetrahedra', 'num cusps', 'symmetry group'),('boundary H1 basis', 'num vertices', 'vertex degrees', 'vertices qtons rep (genus,punctures)', 'num faces', 'top dim faces (<verts>)'),('allows non-admissible', 'num qtons', 'num non-trivial in H2', 'num norm minimizing')]
+        names = [('rank H_2(M;bdy M)', 'volume', 'num tetrahedra', 'num cusps', 'symmetry group'),('num vertices', 'vertex degrees', 'vertices qtons rep (genus,punctures)', 'num faces', 'top dim faces (<verts>)'),('allows non-admissible', 'num qtons', 'num non-trivial in H2', 'num norm minimizing')]
         qtons_inds = [v.qtons_index() for v in B.vertices()]
-        values = [(M.homology().rank(), M.volume(), M.num_tetrahedra(), M.num_cusps(), sym_group), (W.bdy_H1_basis(), len(P.vertices()), [sum(P.vertex_adjacency_matrix()[i]) for i in range(P.n_vertices())], [(v.genus(),v.num_boundary_comps()) for v in B.vertices()], len(P.faces(P.dim()-1)), ['<{}>'.format(' '.join([str(v.index()) for v in face.vertices()])) for face in P.faces(P.dim()-1)]), (W.allows_non_admissible(), W.qtons().size(), len([1 for i in range(W.qtons().size()) if W.over_facet(i)!=None]), len([1 for i in range(W.qtons().size()) if W.is_norm_minimizing(i)]))]
+        values = [(M.homology().rank(), M.volume(), M.num_tetrahedra(), M.num_cusps(), sym_group), (len(P.vertices()), [sum(P.vertex_adjacency_matrix()[i]) for i in range(P.n_vertices())], [(v.genus(),v.num_boundary_comps()) for v in B.vertices()], len(P.faces(P.dim()-1)), ['<{}>'.format(' '.join([str(v.index()) for v in face.vertices()])) for face in P.faces(P.dim()-1)]), (W.allows_non_admissible(), W.qtons().size(), len([1 for i in range(W.qtons().size()) if W.over_facet(i)!=None]), len([1 for i in range(W.qtons().size()) if W.is_norm_minimizing(i)]))]
         summary_page(tnorm_app.SummaryTab, sections, names, values)
         print('Done.')
     except Exception as e: print('Error: {}'.format(e))
