@@ -92,7 +92,7 @@ class NormBall(object):
         return self.polyhedron().face_lattice().hasse_diagram()
 
 
-    def _plot2d(self, dual=False, transparency=.4, show_labels=True, axes=False, highlight_edges=True, label_color=(0,0,0), edge_color=(0,0,1), label_size=12, edge_thickness=1, vertex_size=.06, ball_color=(0,0,1), save_to=None):
+    def _plot2d(self, dual=False, transparency=.4, show_labels=True, axes=True, highlight_edges=True, label_color=(0,0,0), edge_color=(0,0,1), label_size=12, edge_thickness=1, vertex_size=.06, ball_color=(0,0,1), save_to=None):
         labels = Graphics()
         plt0 = self.polyhedron().plot()
         xymax = max(plt0.get_axes_range()['xmax'], plt0.get_axes_range()['ymax'])
